@@ -1,32 +1,21 @@
 #! /bin/bash
 
-if [ ! -x "../platform" ]; then
-	echo "No platform script found, aborting." >&2
-
-	exit 1
-fi
-
-if [ "${PLATFORM}" = "tcl" ]; then
-	rm -rf out
-
-	exit 0
-fi
-
-VERS=3.6.22
+# Define parameters
+VERS=3.7.2
 VERSUNDER="$(echo "${VERS}" | sed 's@\.@_@g')"
 SRC="src/sqlite-${VERSUNDER}.tar.gz"
 SRCURL="http://www.sqlite.org/sqlite-${VERSUNDER}-tea.tar.gz"
-BUILDDIR="sqlite-${VERSUNDER}-tea"
-WORKDIR="${TMPDIR:-/tmp}/sqlite-$$${RANDOM}${RANDOM}${RANDOM}"
-PLATDIR="$(pwd)/out/${PLATFORM}"
+BUILDDIR="sqlite${VERS}"
+export VERS SRC SRCURL BUILDDIR
 
-export VERS SRC SRCURL BUILDDIR WORKDIR PLATDIR
+# Load common functions
+source ../common.sh
 
-if [ ! -f "${SRC}" ]; then
-	mkdir src >/dev/null 2>/dev/null
+# Do not build if the "tcl" platform has been requested
+not_platforms 'tcl'
 
-	wget -O "${SRC}" "${SRCURL}" || exit 1
-fi
+# Download source
+download_src
 
 (
 	rm -rf build
